pub struct TelemetryDisplay<'a, T>(/* private fields */)
where
T: ?Sized;Expand description
Wraps a value so telemetry-safe formatting can be used where Display is expected.
Implementations
Sourceimpl<'a, T> TelemetryDisplay<'a, T>where
T: ToTelemetry + ?Sized,
impl<'a, T> TelemetryDisplay<'a, T>where
T: ToTelemetry + ?Sized,
Sourcepub fn new(value: &'a T) -> TelemetryDisplay<'a, T>
pub fn new(value: &'a T) -> TelemetryDisplay<'a, T>
Creates a Display adapter for telemetry backends that accept %value.